#!%PERL%
# Copyright (c) vhffs project and its contributors
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without 
# modification, are permitted provided that the following conditions 
# are met:
#
# 1. Redistributions of source code must retain the above copyright 
#   notice, this list of conditions and the following disclaimer.
#2. Redistributions in binary form must reproduce the above copyright
#   notice, this list of conditions and the following disclaimer in 
#   the documentation and/or other materials provided with the 
#   distribution.
#3. Neither the name of vhffs nor the names of its contributors 
#   may be used to endorse or promote products derived from this 
#   software without specific prior written permission.
#
#THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
#"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
#LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
#FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE 
#COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
#INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
#BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; 
#LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER 
#CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
# LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN 
# ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
# POSSIBILITY OF SUCH DAMAGE.

use strict;
use utf8;

use POSIX qw(locale_h);
use locale;
use Locale::gettext;
use CGI;

use lib '%VHFFS_LIB_DIR%';
use Vhffs::Panel::Main;
use Vhffs::Panel::Template;
use Vhffs::Panel::User;
use Vhffs::User;

my $panel = new Vhffs::Panel::Main();
exit 0 unless $panel;

$panel->check_public();
my $cgi = $panel->{cgi};
my $vhffs = $panel->{vhffs};
my $templatedir = $panel->{templatedir};

my $username = $cgi->param('name');
my $user;
my $template;

if(!defined $username) {
    $template =  new HTML::Template( filename => $templatedir.'/public/simplemsg.tmpl' );
    my $message = gettext( "CGI Error !");
    $template->param( MESSAGE => $message );
} elsif(!defined($user = Vhffs::User::get_by_username($vhffs, $username))) {
    $template =  new HTML::Template( filename => $templatedir.'/public/simplemsg.tmpl' );
    my $message = gettext( "CGI Error !");
    $template->param( MESSAGE => $message );
} else {
    $template = new Vhffs::Panel::Template( filename => $templatedir.'/public/user.tmpl', loop_context_vars => 1, die_on_bad_params => 0);
    $template->param( OBJECT_ID => $user->get_oid );
    $template->param( USERNAME => $user->get_username );
    $template->param( FIRSTNAME => $user->get_firstname );
    $template->param( LASTNAME => $user->get_lastname );
    $template->param( GROUPS => Vhffs::Panel::User::get_groups($user) );
    $template->param( USE_AVATAR => $panel->use_users_avatars );
}

$panel->light( $template );
$panel->display;
